'use strict';

var marked = require('marked');
var moment = require('moment');
var element = require('./element');

var get = {
  content: function content(page) {
    return page.file.body;
  },
  date: function date(page) {
    return page.file.attributes.date;
  },
  title: function title(page) {
    return page.file.attributes.title;
  }
};

describe('Element', function () {
  it('entries generate xml', function () {
    var baseUrl = 'http://demo.com/';
    var sections = ['demoSection'];
    var title = 'demo title';
    var date = moment('2016-02-21', 'YYYY-MM-DD').utcOffset(0).format();
    var body = 'demo';
    var pages = {
      demo: {
        type: 'page',
        sectionName: 'demoSection',
        file: {
          attributes: {
            date: date,
            title: title
          },
          body: body
        }
      }
    };

    var result = element.entries({
      baseUrl: baseUrl,
      sections: sections,
      pages: pages,
      get: get
    });

    var expected = '<entry>' + '<title>' + title + '</title>' + '<id>ademotitle' + date.toLowerCase() + '</id>' + '<link href="' + baseUrl + 'demo"></link>' + '<updated>' + date + '</updated>' + '<content type="html">' + body + '</content>' + '</entry>';

    expect(result).toEqual(expected);
  });

  it('do not resolve full urls', function () {
    var baseUrl = 'http://demo.com/';
    var sections = ['demoSection'];
    var title = 'demo title';
    var date = moment('2016-02-21', 'YYYY-MM-DD').utcOffset(0).format();
    var body = marked('#test\n[check out](http://google.com)');
    var pages = {
      demo: {
        type: 'page',
        sectionName: 'demoSection',
        file: {
          attributes: {
            date: date,
            title: title
          },
          body: body
        }
      }
    };

    var result = element.entries({
      baseUrl: baseUrl,
      sections: sections,
      pages: pages,
      get: get
    });

    var expected = '<entry>' + '<title>' + title + '</title>' + '<id>ademotitle' + date.toLowerCase() + '</id>' + '<link href="' + baseUrl + 'demo"></link>' + '<updated>' + date + '</updated>' + '<content type="html">&lt;p&gt;#test\n&lt;a href=&quot;http://google.com&quot;&gt;check out&lt;/a&gt;&lt;/p&gt;\n</content>' + '</entry>';

    expect(result).toEqual(expected);
  });

  it('entries resolve relative urls against base', function () {
    var baseUrl = 'http://demo.com/';
    var sections = ['demoSection'];
    var title = 'demo title';
    var date = moment('2016-02-21', 'YYYY-MM-DD').utcOffset(0).format();
    var body = marked('#test\n[check out](../blog/demo-interview)');
    var pages = {
      demo: {
        type: 'page',
        sectionName: 'demoSection',
        file: {
          attributes: {
            date: date,
            title: title
          },
          body: body
        }
      }
    };

    var result = element.entries({
      baseUrl: baseUrl,
      sections: sections,
      pages: pages,
      get: get
    });

    var expected = '<entry>' + '<title>' + title + '</title>' + '<id>ademotitle' + date.toLowerCase() + '</id>' + '<link href="' + baseUrl + 'demo"></link>' + '<updated>' + date + '</updated>' + '<content type="html">&lt;p&gt;#test\n&lt;a href=&quot;http://demo.com/blog/demo-interview&quot;&gt;check out&lt;/a&gt;&lt;/p&gt;\n</content>' + '</entry>';

    expect(result).toEqual(expected);
  });

  it('entries resolve absolute urls against base', function () {
    var baseUrl = 'http://demo.com/';
    var sections = ['demoSection'];
    var title = 'demo title';
    var date = moment('2016-02-21', 'YYYY-MM-DD').utcOffset(0).format();
    var body = marked('#test\n[check out](/blog/demo-interview)');
    var pages = {
      demo: {
        type: 'page',
        sectionName: 'demoSection',
        file: {
          attributes: {
            date: date,
            title: title
          },
          body: body
        }
      }
    };

    var result = element.entries({
      baseUrl: baseUrl,
      sections: sections,
      pages: pages,
      get: get
    });

    var expected = '<entry>' + '<title>' + title + '</title>' + '<id>ademotitle' + date.toLowerCase() + '</id>' + '<link href="' + baseUrl + 'demo"></link>' + '<updated>' + date + '</updated>' + '<content type="html">&lt;p&gt;#test\n&lt;a href=&quot;http://demo.com/blog/demo-interview&quot;&gt;check out&lt;/a&gt;&lt;/p&gt;\n</content>' + '</entry>';

    expect(result).toEqual(expected);
  });

  it('entries resolve relative urls against base', function () {
    var baseUrl = 'http://demo.com/';
    var sections = ['blog'];
    var title = 'demo title';
    var date = moment('2016-02-21', 'YYYY-MM-DD').utcOffset(0).format();
    var body = marked('#test\n[check out](./demo-interview)');
    var pages = {
      demo: {
        type: 'page',
        sectionName: 'blog',
        file: {
          attributes: {
            date: date,
            title: title
          },
          body: body
        }
      }
    };

    var result = element.entries({
      baseUrl: baseUrl,
      sections: sections,
      pages: pages,
      get: get
    });

    var expected = '<entry>' + '<title>' + title + '</title>' + '<id>ademotitle' + date.toLowerCase() + '</id>' + '<link href="' + baseUrl + 'demo"></link>' + '<updated>' + date + '</updated>' + '<content type="html">&lt;p&gt;#test\n&lt;a href=&quot;http://demo.com/blog/demo-interview&quot;&gt;check out&lt;/a&gt;&lt;/p&gt;\n</content>' + '</entry>';

    expect(result).toEqual(expected);
  });
});